bruker2nifti package
====================

Subpackages
-----------

.. toctree::

    bruker2nifti.parsers

Submodules
----------

bruker2nifti.converter module
-----------------------------

.. automodule:: bruker2nifti.converter
    :members:
    :undoc-members:
    :show-inheritance:

bruker2nifti.open_GUI module
----------------------------

.. automodule:: bruker2nifti.open_GUI
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: bruker2nifti
    :members:
    :undoc-members:
    :show-inheritance:
